pub struct FeesEstimateIdentifier {
    pub marketplace_id: Option<String>,
    pub seller_id: Option<String>,
    pub id_type: Option<IdType>,
    pub id_value: Option<String>,
    pub is_amazon_fulfilled: Option<bool>,
    pub price_to_estimate_fees: Option<Box<PriceToEstimateFees>>,
    pub seller_input_identifier: Option<String>,
    pub optional_fulfillment_program: Option<OptionalFulfillmentProgram>,
}
FeesEstimateIdentifier : An item identifier, marketplace, time of request, and other details that identify an estimate.

Fields

marketplace_id: Option<String>

A marketplace identifier.

seller_id: Option<String>

The seller identifier.

id_type: Option<IdType>id_value: Option<String>

The item identifier.

is_amazon_fulfilled: Option<bool>

When true, the offer is fulfilled by Amazon.

price_to_estimate_fees: Option<Box<PriceToEstimateFees>>seller_input_identifier: Option<String>

A unique identifier provided by the caller to track this request.

optional_fulfillment_program: Option<OptionalFulfillmentProgram>

Implementations

An item identifier, marketplace, time of request, and other details that identify an estimate.